@@ -46,7 +46,8 @@ def PID_controller(model, var0, t, param, ylimit, w, y0 = 0, PID = [0,0,0], Tt =
     e_final = np.zeros(len(t))
     e = w
     KP, KI, KD = PID
-
+    Int_e = 0
+    
     # empty dataframe for saving results
     results = list(range(len(t)))
 
@@ -86,10 +87,15 @@ def PID_controller(model, var0, t, param, ylimit, w, y0 = 0, PID = [0,0,0], Tt =
         e = e_temp
         e_final[i] = e_temp
         P = KP * e
+        if y<ylimit[1] and y>ylimit[0]:
+            Int_e = Int_e + e *(t[i+1]-t[i])
+        else: Int_e = Int_e + 0
         # I component
-        I = KI* e*(t[i+1]-t[1])
+        I = KI*Int_e
         
-        y = y0 + P + I + D
+        
+        
+        y = y0 + P + I - D
         y = max(min(y, ylimit[1]), ylimit[0])
         
     results[len(t)-1] = results[len(t)-2]
