@@ -17,7 +17,9 @@ def delay(time, var, delay, value = 0):
     """
     DT = time[1]-time[0]
     i_delay = int(round(delay/DT))
-        
+    if np.ndim(var)!= 1: var = var[:,-1]
+    else: pass
+    
     var_delayed = np.zeros(len(var))
     var_delayed[0:i_delay] = value
     var_delayed[i_delay:] = var[0:-i_delay]
