@@ -30,7 +30,7 @@ def fft(data):
     frq = k/p
     
     # amplitude (y-axis)
-    amp = sp.fft.fft(y)
+    amp = sp.fft.fft(np.array(y))
     
     # normalize amplitude
     amp = abs(amp/len(y)*2)
